@@ -1,20 +1,24 @@
 "mselect" <- function(object, fctList = NULL, nested = FALSE)
 {
     if (!is.logical(nested)) {stop("'nested' argument takes only the values: FALSE, TRUE")}
+    
+    contData <- identical(object$"type", "continuous")
+    nestedInd <- 3 + contData + nested
+    
 #    if (missing(fctList)) 
 #    {
 #        return(object)
 #    } else {
-        mc <- match.call()
+    mc <- match.call()
         
-        lenFL <- length(fctList) 
-        retMat <- matrix(0, lenFL + 1, 4 + nested)
+    lenFL <- length(fctList) 
+    retMat <- matrix(0, lenFL + 1, 3 + contData + nested)
 
-        retMat[1 ,1] <- logLik(object)
-        retMat[1, 2] <- AIC(object)
-        retMat[1, 3] <- summary(object)$"resVar"
-        retMat[1, 4] <- anova(object)[2, 5]
-        if (nested) {retMat[1, 5] <- NA}
+    retMat[1 ,1] <- logLik(object)
+    retMat[1, 2] <- AIC(object)
+    retMat[1, 3] <- modelFit(object)[2, 5]
+    if (contData) {retMat[1, 4] <- summary(object)$"resVar"}
+    if (nested) {retMat[1, nestedInd] <- NA}
 
 #        fctList2 <- list()
 #        fctList2[[1]] <- deparse((object$"call"$"fct"))
@@ -22,9 +26,8 @@
 #        retList <- list()
 #        retList[[1]] <- object
 
-        fctList2 <- rep("", lenFL + 1)        
-        fctList2[1] <- deparse((object$"call"$"fct"))        
-    
+    fctList2 <- rep("", lenFL + 1)        
+    fctList2[1] <- deparse((object$"call"$"fct"))        
        
     if (!is.null(fctList))
     {
@@ -47,12 +50,16 @@
             
                 retMat[i+1, 1] <- logLik(tempObj)
                 retMat[i+1, 2] <- AIC(tempObj)
-                retMat[i+1, 3] <- summary(tempObj)$"resVar"
-                retMat[i+1, 4] <- anova(tempObj)[2, 5]
+                retMat[i+1, 3] <- modelFit(tempObj)[2, 5]
+                
+                if (contData)
+                {
+                    retMat[i+1, 4] <- summary(tempObj)$"resVar"
+                }                
                 
                 if (nested) 
                 {
-                    retMat[i+1, 5] <- anova(prevObj, tempObj, details = FALSE)[2, 5]  # extracting p-value
+                    retMat[i+1, nestedInd] <- anova(prevObj, tempObj, details = FALSE)[2, 5]  # extracting p-value
                 }  
             } else {
                 retMat[i+1, ] <- NA
@@ -63,7 +70,8 @@
 #    }
     rownames(retMat) <- as.vector(unlist(fctList2))
     
-    cnames <- c("logLik", "AIC", "Res var", "Lack of fit")
+    cnames <- c("logLik", "AIC", "Lack of fit")
+    if (contData) {cnames <- c(cnames, "Res var")}
     if (nested) {cnames <- c(cnames, "Nested F test")}
     colnames(retMat) <- cnames
     
